==> jc-1.4.0.tar.gz: polyglot/types/LoadedClassResolver.h <==
// public class polyglot.types.LoadedClassResolver

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class eec1a4cebd785b9d polyglot_types_ClassResolver
// @dep_class 775d491e1eb77426 polyglot_types_LoadedClassResolver

// header file dependencies
// @dep_header polyglot_types_ClassResolver

#include "polyglot/types/ClassResolver.h"

#ifndef _JC_polyglot_types_LoadedClassResolver_H_
#define _JC_polyglot_types_LoadedClassResolver_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Set$object;
struct _jc_polyglot_main_Version$object;
struct _jc_polyglot_types_ClassType$object;
struct _jc_polyglot_types_Named$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_types_reflect_ClassFile$object;
struct _jc_polyglot_types_reflect_ClassFileLoader$object;
struct _jc_polyglot_types_reflect_ClassPathLoader$object;
struct _jc_polyglot_util_TypeEncoder$object;

// Typedefs
typedef struct _jc_polyglot_types_LoadedClassResolver$sub_refs	_jc_polyglot_types_LoadedClassResolver$sub_refs;
typedef struct _jc_polyglot_types_LoadedClassResolver$sub_nonrefs	_jc_polyglot_types_LoadedClassResolver$sub_nonrefs;
typedef struct _jc_polyglot_types_LoadedClassResolver$refs	_jc_polyglot_types_LoadedClassResolver$refs;
typedef struct _jc_polyglot_types_LoadedClassResolver$nonrefs	_jc_polyglot_types_LoadedClassResolver$nonrefs;
typedef struct _jc_polyglot_types_LoadedClassResolver$object	_jc_polyglot_types_LoadedClassResolver$object;

typedef struct _jc_polyglot_types_LoadedClassResolver$fields_struct	_jc_polyglot_types_LoadedClassResolver$fields_struct;
typedef const struct _jc_polyglot_types_LoadedClassResolver$vmethods	_jc_polyglot_types_LoadedClassResolver$vmethods;
typedef const struct _jc_polyglot_types_LoadedClassResolver$vtable	_jc_polyglot_types_LoadedClassResolver$vtable;
typedef const struct _jc_polyglot_types_LoadedClassResolver$vtype	_jc_polyglot_types_LoadedClassResolver$vtype;

// Class fields structure
struct _jc_polyglot_types_LoadedClassResolver$fields_struct {
	struct _jc_object	*report__5ftopics;
	jint	COMPATIBLE;
	jint	MINOR__5fNOT__5fCOMPATIBLE;
	jint	NOT__5fCOMPATIBLE;
};
extern _jc_polyglot_types_LoadedClassResolver$fields_struct _jc_polyglot_types_LoadedClassResolver$class_fields;

// Constructors
extern void _jc_polyglot_types_LoadedClassResolver$method$_init$4496cf846523face(_jc_env *, struct _jc_polyglot_types_LoadedClassResolver$object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_types_reflect_ClassFileLoader$object *, struct _jc_polyglot_main_Version$object *, jboolean);

// Virtual methods
extern jint _jc_polyglot_types_LoadedClassResolver$method$checkCompilerVersion$06ae3cf9489417d8(_jc_env *, struct _jc_polyglot_types_LoadedClassResolver$object *, struct _jc_java_lang_String$object *);
extern struct _jc_object *_jc_polyglot_types_LoadedClassResolver$method$find$6acc62ea1c707b3c(_jc_env *, struct _jc_polyglot_types_LoadedClassResolver$object *, struct _jc_java_lang_String$object *);
extern struct _jc_object *_jc_polyglot_types_LoadedClassResolver$method$getEncodedType$2d027e16f96acd78(_jc_env *, struct _jc_polyglot_types_LoadedClassResolver$object *, struct _jc_polyglot_types_reflect_ClassFile$object *, struct _jc_java_lang_String$object *);
extern struct _jc_polyglot_types_reflect_ClassFile$object *_jc_polyglot_types_LoadedClassResolver$method$loadFile$6eba5e5275043e6e(_jc_env *, struct _jc_polyglot_types_LoadedClassResolver$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_types_LoadedClassResolver$method_info$checkCompilerVersion$06ae3cf9489417d8;
extern _jc_method _jc_polyglot_types_LoadedClassResolver$method_info$find$6acc62ea1c707b3c;
extern _jc_method _jc_polyglot_types_LoadedClassResolver$method_info$getEncodedType$2d027e16f96acd78;
extern _jc_method _jc_polyglot_types_LoadedClassResolver$method_info$loadFile$6eba5e5275043e6e;

// Static methods
extern void _jc_polyglot_types_LoadedClassResolver$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_polyglot_types_LoadedClassResolver$vmethods {
	jint	(*checkCompilerVersion$06ae3cf9489417d8)(_jc_env *, struct _jc_polyglot_types_LoadedClassResolver$object *, struct _jc_java_lang_String$object *);
	struct _jc_object	*(*find$6acc62ea1c707b3c)(_jc_env *, struct _jc_polyglot_types_LoadedClassResolver$object *, struct _jc_java_lang_String$object *);
	struct _jc_object	*(*getEncodedType$2d027e16f96acd78)(_jc_env *, struct _jc_polyglot_types_LoadedClassResolver$object *, struct _jc_polyglot_types_reflect_ClassFile$object *, struct _jc_java_lang_String$object *);
	struct _jc_polyglot_types_reflect_ClassFile$object	*(*loadFile$6eba5e5275043e6e)(_jc_env *, struct _jc_polyglot_types_LoadedClassResolver$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_polyglot_types_LoadedClassResolver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_ClassResolver$vmethods	polyglot_types_ClassResolver;
	_jc_polyglot_types_LoadedClassResolver$vmethods	polyglot_types_LoadedClassResolver;
};

// Vtype
struct _jc_polyglot_types_LoadedClassResolver$vtype {
	_jc_type			type;
	_jc_polyglot_types_LoadedClassResolver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_LoadedClassResolver$sub_refs {
	struct _jc_object	*ts;
	struct _jc_polyglot_util_TypeEncoder$object	*te;
	struct _jc_polyglot_types_reflect_ClassPathLoader$object	*loader;
	struct _jc_polyglot_main_Version$object	*version;
	struct _jc_object	*nocache;
};

// Reference instance fields (object)
struct _jc_polyglot_types_LoadedClassResolver$refs {
    _jc_polyglot_types_LoadedClassResolver$sub_refs	polyglot_types_LoadedClassResolver;
    _jc_polyglot_types_ClassResolver$sub_refs	polyglot_types_ClassResolver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_LoadedClassResolver$sub_nonrefs {
	jboolean	allowRawClasses;
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_LoadedClassResolver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_ClassResolver$sub_nonrefs	polyglot_types_ClassResolver;
    _jc_polyglot_types_LoadedClassResolver$sub_nonrefs	polyglot_types_LoadedClassResolver;
};

// Object instance structure
struct _jc_polyglot_types_LoadedClassResolver$object {
	_jc_polyglot_types_LoadedClassResolver$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_LoadedClassResolver$vtype	*vtype;
	_jc_polyglot_types_LoadedClassResolver$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_LoadedClassResolver$vtype _jc_polyglot_types_LoadedClassResolver$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_LoadedClassResolver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_LoadedClassResolver$class_object;

#endif	/* _JC_polyglot_types_LoadedClassResolver_H_ */

==> jc-1.4.6.tar.gz: polyglot/types/LoadedClassResolver.h <==
// public class polyglot.types.LoadedClassResolver

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class eec1a4cebd785b9d polyglot_types_ClassResolver
// @dep_class 775d491e1eb77426 polyglot_types_LoadedClassResolver

// header file dependencies
// @dep_header polyglot_types_ClassResolver

#include "polyglot/types/ClassResolver.h"

#ifndef _JC_polyglot_types_LoadedClassResolver_H_
#define _JC_polyglot_types_LoadedClassResolver_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Set$object;
struct _jc_polyglot_main_Version$object;
struct _jc_polyglot_types_ClassType$object;
struct _jc_polyglot_types_Named$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_types_reflect_ClassFile$object;
struct _jc_polyglot_types_reflect_ClassFileLoader$object;
struct _jc_polyglot_types_reflect_ClassPathLoader$object;
struct _jc_polyglot_util_TypeEncoder$object;

// Typedefs
typedef struct _jc_polyglot_types_LoadedClassResolver$sub_refs	_jc_polyglot_types_LoadedClassResolver$sub_refs;
typedef struct _jc_polyglot_types_LoadedClassResolver$sub_nonrefs	_jc_polyglot_types_LoadedClassResolver$sub_nonrefs;
typedef struct _jc_polyglot_types_LoadedClassResolver$refs	_jc_polyglot_types_LoadedClassResolver$refs;
typedef struct _jc_polyglot_types_LoadedClassResolver$nonrefs	_jc_polyglot_types_LoadedClassResolver$nonrefs;
typedef struct _jc_polyglot_types_LoadedClassResolver$object	_jc_polyglot_types_LoadedClassResolver$object;

typedef struct _jc_polyglot_types_LoadedClassResolver$fields_struct	_jc_polyglot_types_LoadedClassResolver$fields_struct;
typedef const struct _jc_polyglot_types_LoadedClassResolver$vmethods	_jc_polyglot_types_LoadedClassResolver$vmethods;
typedef const struct _jc_polyglot_types_LoadedClassResolver$vtable	_jc_polyglot_types_LoadedClassResolver$vtable;
typedef const struct _jc_polyglot_types_LoadedClassResolver$vtype	_jc_polyglot_types_LoadedClassResolver$vtype;

// Class fields structure
struct _jc_polyglot_types_LoadedClassResolver$fields_struct {
	struct _jc_object	*report__5ftopics;
	jint	COMPATIBLE;
	jint	MINOR__5fNOT__5fCOMPATIBLE;
	jint	NOT__5fCOMPATIBLE;
};
extern _jc_polyglot_types_LoadedClassResolver$fields_struct _jc_polyglot_types_LoadedClassResolver$class_fields;

// Constructors
extern void _jc_polyglot_types_LoadedClassResolver$method$_init$4496cf846523face(_jc_env *, struct _jc_polyglot_types_LoadedClassResolver$object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_types_reflect_ClassFileLoader$object *, struct _jc_polyglot_main_Version$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_polyglot_types_LoadedClassResolver$method$checkCompilerVersion$06ae3cf9489417d8(_jc_env *, struct _jc_polyglot_types_LoadedClassResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_types_LoadedClassResolver$method$find$6acc62ea1c707b3c(_jc_env *, struct _jc_polyglot_types_LoadedClassResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_types_LoadedClassResolver$method$getEncodedType$2d027e16f96acd78(_jc_env *, struct _jc_polyglot_types_LoadedClassResolver$object *, struct _jc_polyglot_types_reflect_ClassFile$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_types_reflect_ClassFile$object *_jc_polyglot_types_LoadedClassResolver$method$loadFile$6eba5e5275043e6e(_jc_env *, struct _jc_polyglot_types_LoadedClassResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_types_LoadedClassResolver$method_info$checkCompilerVersion$06ae3cf9489417d8;
extern _jc_method _jc_polyglot_types_LoadedClassResolver$method_info$find$6acc62ea1c707b3c;
extern _jc_method _jc_polyglot_types_LoadedClassResolver$method_info$getEncodedType$2d027e16f96acd78;
extern _jc_method _jc_polyglot_types_LoadedClassResolver$method_info$loadFile$6eba5e5275043e6e;

// Static methods
extern void _jc_polyglot_types_LoadedClassResolver$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_types_LoadedClassResolver$vmethods {
	jint	(*checkCompilerVersion$06ae3cf9489417d8)(_jc_env *, struct _jc_polyglot_types_LoadedClassResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*find$6acc62ea1c707b3c)(_jc_env *, struct _jc_polyglot_types_LoadedClassResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getEncodedType$2d027e16f96acd78)(_jc_env *, struct _jc_polyglot_types_LoadedClassResolver$object *, struct _jc_polyglot_types_reflect_ClassFile$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_polyglot_types_reflect_ClassFile$object	*(*loadFile$6eba5e5275043e6e)(_jc_env *, struct _jc_polyglot_types_LoadedClassResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_types_LoadedClassResolver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_ClassResolver$vmethods	polyglot_types_ClassResolver;
	_jc_polyglot_types_LoadedClassResolver$vmethods	polyglot_types_LoadedClassResolver;
};

// Vtype
struct _jc_polyglot_types_LoadedClassResolver$vtype {
	_jc_type			type;
	_jc_polyglot_types_LoadedClassResolver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_LoadedClassResolver$sub_refs {
	struct _jc_object	*ts;
	struct _jc_polyglot_util_TypeEncoder$object	*te;
	struct _jc_polyglot_types_reflect_ClassPathLoader$object	*loader;
	struct _jc_polyglot_main_Version$object	*version;
	struct _jc_object	*nocache;
};

// Reference instance fields (object)
struct _jc_polyglot_types_LoadedClassResolver$refs {
    _jc_polyglot_types_LoadedClassResolver$sub_refs	polyglot_types_LoadedClassResolver;
    _jc_polyglot_types_ClassResolver$sub_refs	polyglot_types_ClassResolver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_LoadedClassResolver$sub_nonrefs {
	jboolean	allowRawClasses;
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_LoadedClassResolver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_ClassResolver$sub_nonrefs	polyglot_types_ClassResolver;
    _jc_polyglot_types_LoadedClassResolver$sub_nonrefs	polyglot_types_LoadedClassResolver;
};

// Object instance structure
struct _jc_polyglot_types_LoadedClassResolver$object {
	_jc_polyglot_types_LoadedClassResolver$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_LoadedClassResolver$vtype	*vtype;
	_jc_polyglot_types_LoadedClassResolver$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_LoadedClassResolver$vtype _jc_polyglot_types_LoadedClassResolver$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_LoadedClassResolver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_LoadedClassResolver$class_object;

#endif	/* _JC_polyglot_types_LoadedClassResolver_H_ */
